<?php 

//use App\Models\Settings;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


/**
 * Add custom data to cart item on add to cart event.
 */

function wbdl_add_cart_item_data( $cart_item_meta, $productID, $bundleTitle, $bundleImage, $bundleSalePrice, $bundleRegularPrice, $useCustomVar, $customVariations) {
	
	$custom_data  = array() ;

	$custom_data ['use_custom_variations'] = $useCustomVar;

	if($useCustomVar == 'on') {
		$custom_data [ 'bundle_title' ] = $bundleTitle;
		$custom_data ['custom_bundle_image'] = $bundleImage;
		$custom_data ['sale_price'] = $bundleSalePrice;
		$custom_data ['regular_price'] = $bundleRegularPrice;
		$custom_data [ 'multiline_price' ] = false;
		$custom_data [ 'option1_name' ] = $customVariations[0]['option1_name'];
		$custom_data [ 'option2_name' ] = $customVariations[0]['option2_name'];
		for($i=0; $i<count($customVariations); $i++){
			$custom_data [ 'option1_value' ] .= ($i == count($customVariations)-1) ? $customVariations[$i]['option1_value'] : $customVariations[$i]['option1_value'].", ";
			$custom_data [ 'option2_value' ] .= ($i == count($customVariations)-1) ? $customVariations[$i]['option2_value'] : $customVariations[$i]['option2_value'].", ";
		}
		
	}
	
	$cart_item_meta ['wbdl_custom_data'] = $custom_data ;
	
	return $cart_item_meta;
}


/**
 * Display custom product data on cart and checkout pages.
 */

add_filter( 'woocommerce_get_item_data', 'wbdl_get_item_data' , 10, 2 );

function wbdl_get_item_data ( $other_data, $cart_item ) {

	if(is_null($cart_item['data'])){
		return $other_data;
	}

	if (is_a($cart_item['data'], 'WC_Product')) {

		if ( $cart_item[ 'wbdl_custom_data' ] ) {

			$custom_data  = $cart_item [ 'wbdl_custom_data' ];
			if( $custom_data['use_custom_variations'] == 'on'){
				$other_data[] = array( 'name' => 'Offer', 'display'  => $custom_data['bundle_title'] );
				//$other_data[] = array( 'name' => 'Custom Var', 'display'  => $custom_data['use_custom_variations'] );
				//$other_data[] = array( 'name' => 'Regular Price', 'display'  => $custom_data['regular_price'] );
				//$other_data[] = array( 'name' => 'Sale Price', 'display'  => $custom_data['sale_price'] );
				
				if($custom_data['option1_name'] != NULL) {
					$other_data[] = array( 'name' => $custom_data['option1_name'], 'display'  => $custom_data['option1_value'] );
				}
				
				if($custom_data['option2_name'] != NULL) {
					$other_data[] = array( 'name' => $custom_data['option2_name'], 'display'  => $custom_data['option2_value'] );
				}
			}
				
		}
	}
	
	return $other_data;
}


/**
 * Edit the price html in the cart to show the price strikeout
 */

add_filter( 'woocommerce_cart_item_price', 'wbdl_replace_cart_item_price', 10, 3 );
function wbdl_replace_cart_item_price( $price, $cart_item, $cart_item_key ) {

	if(is_null($cart_item['data'])){
            return $price_html;
	}

	if (is_a($cart_item['data'], 'WC_Product')) {

		if ( $cart_item[ 'wbdl_custom_data' ] ) {

			if(getStrikeoutPriceHtml($cart_item) != ""){
				$price = getStrikeoutPriceHtml($cart_item);
			}
		}
	}
	return $price;
    
}


/**
 * Build the Strikout Price HTML (to show on cart page) based on the product discount
 */

function getStrikeoutPriceHtml($cart_item) {

	$price_html = "";
	
	// Check if use custom variations is selected. This will have an impact on how to display prices (bundle price VS item price)
	
	//$settings = Settings::getSettings();
	$useCustomVariations = ($cart_item['wbdl_custom_data']['use_custom_variations']!=NULL) ? $cart_item['wbdl_custom_data']['use_custom_variations'] : 'off';

	// Get the regular & sale prices
	$salePrice = $cart_item['wbdl_custom_data']['sale_price'];
	$regularPrice = ($useCustomVariations == 'off') ? $cart_item['data']->get_regular_price() : $cart_item['wbdl_custom_data']['regular_price'];
	
	// Check if the item shows multiline price
	$isMultiLine = $cart_item['wbdl_custom_data']['multiline_price'];
	$qty = $cart_item['quantity'] - 1;

	$price_html = '<div class="wbdl_cart_strikeout_line">';

    if( $regularPrice && ($regularPrice != $salePrice) ){
    	// Format the regular price with Woocommerce currency
		if($useCustomVariations == 'off') $regularPrice = wc_price($regularPrice);
		$price_html .= '<del><span class="woocommerce-Price-amount amount"><bdi>'.$regularPrice.'</bdi></span></del>&nbsp;<ins><span class="woocommerce-Price-amount amount"><bdi>';
    }
    else{
    	// Skip the regular price and do not display it
    	$price_html .= '<ins><span class="woocommerce-Price-amount amount"><bdi>';
    }

    if($isMultiLine){	 // The price has to be displayed in multiple lines to match the bundle price

    	// Calculate the last item displayed price
    	$lastItemSubtotal = $salePrice * $cart_item['quantity'];
    	$salePrice = number_format(round($salePrice,2),2);
    	$lastItemAdjustedPrice = $lastItemSubtotal - ( $salePrice * ($cart_item['quantity'] - 1) );

    	// Format the prices with the store's currency
    	$salePrice = wc_price($salePrice);
    	$lastItemAdjustedPrice = wc_price($lastItemAdjustedPrice);

    	// Build the final price Html
    	$price_html .= $salePrice.'</bdi></span></ins>';
		$price_html .= '&nbsp;x&nbsp;'.$qty.'</div>';
		$price_html .= '<div class="wbdl_cart_strikeout_line"><del><span class="woocommerce-Price-amount amount"><bdi>';
		$price_html .= $regularPrice.'</bdi></span></del>&nbsp;<ins><span class="woocommerce-Price-amount amount"><bdi>'.$lastItemAdjustedPrice.'</bdi></span></ins>';
		$price_html .= '&nbsp;x&nbsp;1';
	}
	else {
		if($useCustomVariations == 'off') $salePrice = wc_price($salePrice);
		$price_html .= $salePrice.'</bdi></span></ins>';
	}

	$price_html .= '</div>';

	return $price_html;
                
}


/**
 * Display the bundle's image instead of product's image if the custom variations option is selected
 */

add_filter( 'woocommerce_cart_item_thumbnail', 'wbdl_product_image_on_cart', 10, 3 );

function wbdl_product_image_on_cart($_product_img, $cart_item, $cart_item_key ) {

    if($cart_item['wbdl_custom_data']['use_custom_variations'] == 'on' && !empty($cart_item['wbdl_custom_data']['custom_bundle_image']) ){
        return '<img src="'.$cart_item['wbdl_custom_data']['custom_bundle_image'].'" />';
    
    }

    return $_product_img;
}


/**
 * @function to cut a number to 2 decimals without rounding up. Useful for calculation of discount prices.
 * @return float
 */

function cutNum($num, $precision = 2) {
    return floor($num) . substr(str_replace(floor($num), '', $num), 0, $precision + 1);
}


/**
 * @function       WooCommerce Show Product Image @ Checkout Page
 
add_filter( 'woocommerce_cart_item_name', 'wbdl_product_image_on_checkout', 10, 3 );
 
function wbdl_product_image_on_checkout( $name, $cart_item, $cart_item_key ) {
     
    if ( ! is_checkout() ) {
        return $name;
    }

    if($cart_item['wbdl_custom_data']['use_custom_variations'] == 'on' && !empty($cart_item['wbdl_custom_data']['custom_bundle_image']) ){
    	
    	$thumbnail= '<img style="float:left;" width="50" height="50" src="'.$cart_item['wbdl_custom_data']['custom_bundle_image'].'">';
    	$thumbnail = '<span class="product-name__thumbnail" style="float: left; padding-right: 15px">'.$thumbnail. '</span>';
    	return $thumbnail;

    }

    return $name;
}
*/


/**
 * Add order item meta
 */

add_action( 'woocommerce_add_order_item_meta', 'wbdl_add_order_item_meta' , 10, 2);
function wbdl_add_order_item_meta ( $item_id, $cart_item ) {

    if ( isset( $cart_item [ 'custom_data' ] ) ) {

        $custom_data  = $cart_item [ 'custom_data' ];
        
        wc_add_order_item_meta( $item_id, 'Offer', $custom_data['bundle_title'] );
        wc_add_order_item_meta( $item_id, 'Color', $custom_data['bundle_color'] );
        wc_add_order_item_meta( $item_id, 'Size', $custom_data['bundle_size'] );
        wc_add_order_item_meta( $item_id, 'Price', $custom_data['bundle_hidden_price'] );
    }
}
