<?php

// use App\Controllers\BundleController;
// use App\Models\Settings;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

/**
 * Update the custom data price of all cart items for a specific product
 */

function wbdl_update_all_custom_data_price_in_cart(){

    $productsInCart = wbdl_get_products_in_cart();
    
    if(empty(WC()->cart->cart_contents)) return;
    
    if(empty($productsInCart)) return;

    foreach( $productsInCart as $productID ) {

        $qtyInCart = $cartItemCount = 0;
        
        foreach(WC()->cart->cart_contents  as $key => $cart_item ) {
            if( $cart_item['product_id'] == $productID ){
                $qtyInCart += $cart_item['quantity'];
                $cartItemCount++; // check if this item is the only one with bundles in cart for this product ID
            }
        }
        
        $discountedTotal = wbdl_calculate_discounted_total($productID,$qtyInCart);
        $unitPrice = $discountedTotal / $qtyInCart;

        if(strpos(strrev($unitPrice), wc_get_price_decimal_separator()) >= 3) { // Woocommerce rounding issue will occur.
            //echo "Rounding issue may occur, we need to fix this!<br>";

            foreach(WC()->cart->cart_contents as $key => $cart_item){
                //echo "Cart Item Key = ".$key."<br>";
                if($cart_item['product_id'] == $productID){
                    $unitPrice = number_format(round($unitPrice,2),2);

                    if($cartItemCount > 1){ // Not the last item in the cart
                        $cart_item['wbdl_custom_data']['sale_price'] = number_format($unitPrice,2);
                        $cart_item['wbdl_custom_data']['multiline_price'] = false;
                        //echo "not last item = ".$cart_item['wbdl_custom_data']['sale_price']." ".$cart_item['wbdl_custom_data']['last_item_price']."<br>";
                    }
                    else { // Last item in the cart
                        $lastItemUnitPrice = ($discountedTotal - ( $unitPrice * ($qtyInCart - $cart_item['quantity']) ) ) / $cart_item['quantity'];
                        $cart_item['wbdl_custom_data']['sale_price'] = $lastItemUnitPrice;
                        $cart_item['wbdl_custom_data']['multiline_price'] = ($cart_item['quantity'] > 1); // this is to show multiple lines in get_price_html
                        //echo "last item = ".$cart_item['wbdl_custom_data']['sale_price']." ".$cart_item['wbdl_custom_data']['last_item_price']."<br>";
                    }
                    $cartItemCount--;
                    WC()->cart->cart_contents[$key] = $cart_item;
                }
            }
        }
        else {

            foreach(WC()->cart->cart_contents as $key => $cart_item){
                
                if($cart_item['product_id'] == $productID){
                    $cart_item['wbdl_custom_data']['sale_price'] = $unitPrice;
                    $cart_item['wbdl_custom_data']['multiline_price'] = false;
                }
                
                WC()->cart->cart_contents[$key] = $cart_item;
            }
        }
        
    }

    WC()->cart->set_session();
}

/**
 * Calculate the discounted total based on the bundles prices
 */

function wbdl_calculate_discounted_total($productID,$qtyInCart) {

    $discountedTotal = 0;
    $bundleController = new BundleController();

    $availableBundles = $bundleController->getBundlesByProductIDSortByQtyDesc($productID);

    $i = $qtyInCart;
    
    // Calculate the discounted price

    foreach($availableBundles as $bundle){
        if( $i >= $bundle->number_of_products ){
            $maxBundlesNb = intval( $i / $bundle->number_of_products );
            if($bundle->sale_price) $discountedTotal += $bundle->sale_price * $maxBundlesNb;
            else $discountedTotal += $bundle->regular_price * $maxBundlesNb;
            $i -= $bundle->number_of_products * $maxBundlesNb;
        }
        if($i == 0) break;
    }

    return $discountedTotal;
}


/**
 * Override product's price in cart with the discounted price
 */

add_action( 'woocommerce_before_calculate_totals', 'wbdl_add_custom_item_price', 10 );
function wbdl_add_custom_item_price( $cart_object ) {

    if ( is_admin() && ! defined( 'DOING_AJAX' ) )
        return;

    $cart_items = $cart_object->cart_contents;
    if ( ! empty( $cart_items ) ) {
        foreach ( $cart_items as $cart_item ) {

            if($cart_item['wbdl_custom_data']){
                if($cart_item['wbdl_custom_data']['sale_price'])
                    $cart_item['data']->set_price($cart_item['wbdl_custom_data']['sale_price']);
                
            }
        }
    }
}


/**
 * Recalculate prices in cart when an item is removed. Only if Woocommerce native variations are used (Custom variations = off).
 */

add_action( 'woocommerce_cart_item_removed', 'wbdl_update_cart_prices_after_remove', 10, 2 );

function wbdl_update_cart_prices_after_remove( $cart_item_key, $cart ) {
    if(WC()->cart->cart_contents_count != 0){
        $cart_item = WC()->cart->get_cart_item( $cart_item_key );
        //$settings = Settings::getSettings();
        if($cart_item['wbdl_custom_data']['use_custom_variations'] == 'off'){
            wbdl_update_all_custom_data_price_in_cart();    
        }
    }
}


/**
 * Recalculate prices in cart when quantity is updated. Only if Woocommerce native variations are used (Custom variations = off).
 */

add_action( 'woocommerce_after_cart_item_quantity_update', 'wbdl_update_cart_prices_after_quantity_update', 10, 3 );

function wbdl_update_cart_prices_after_quantity_update( $cart_item_key,  $quantity,  $old_quantity ) {
    if(WC()->cart->cart_contents_count != 0){
        $cart_item = WC()->cart->get_cart_item( $cart_item_key );
        //$settings = Settings::getSettings();
        if($cart_item['wbdl_custom_data']['use_custom_variations'] == 'off'){
            wbdl_update_all_custom_data_price_in_cart();    
        }   
    }
}

/**
 *  Get IDs of Woobundles products in cart
 */

function wbdl_get_products_in_cart(){

    $productsInCart = array();

    if(WC()->cart->cart_contents_count != 0){
        foreach(WC()->cart->cart_contents as $cart_item_key => $cart_item ) {
            if($cart_item['wbdl_custom_data'] && !in_array($cart_item['product_id'], $productsInCart) ){
                array_push($productsInCart, $cart_item['product_id']);
            }    
        }
    }
    return $productsInCart;
}